@@ -3,19 +3,19 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let mut backend = BitMapBackend::new("examples/outputs/histogram.png", (640, 480));
     backend.open()?;
     let root: DrawingArea<_, _> = backend.into();
-    let font = Into::<FontDesc>::into("Arial").resize(20.0);
+    let font = Into::<FontDesc>::into("Arial").resize(50.0);
     root.fill(&RGBColor(255, 255, 255))?;
 
     let mut chart = ChartBuilder::on(&root)
-        .set_x_label_size(40)
-        .set_y_label_size(40)
+        .x_label_area_size(25)
+        .y_label_area_size(40)
         .caption("Histogram Test", &font)
-        .build_ranged::<RangedCoordu32, RangedCoordu32, _, _>(0..10, 0..10);
+        .build_ranged(0u32..10u32, 0u32..10u32);
 
     chart
         .configure_mesh()
         .disable_x_mesh()
-        .line_style_1(&Into::into(&RGBColor(255, 255, 255).mix(0.3)))
+        .line_style_1(&RGBColor(255, 255, 255).mix(0.3))
         .x_label_offset(30)
         .draw()?;
 
