@@ -11,7 +11,9 @@ use std::fmt::Debug;
 use std::marker::PhantomData;
 use std::ops::Range;
 
-use crate::coord::{AsRangedCoord, CoordTranslate, MeshLine, Ranged, RangedCoord, Shift};
+use crate::coord::{
+    AsRangedCoord, CoordTranslate, MeshLine, Ranged, RangedCoord, ReverseCoordTranslate, Shift,
+};
 use crate::drawing::backend::BackendCoord;
 use crate::drawing::backend::DrawingBackend;
 use crate::drawing::{DrawingArea, DrawingAreaErrorKind};
@@ -354,6 +356,16 @@ impl<
     }
 }
 
+impl<DB: DrawingBackend, CT: ReverseCoordTranslate> ChartContext<DB, CT> {
+    /// Convert the chart context into an closure that can be used for coordinate translation
+    pub fn into_coord_trans(self) -> impl Fn(BackendCoord) -> Option<CT::From> {
+        let coord_spec = self.drawing_area.into_coord_spec();
+        return move |coord| {
+            return coord_spec.reverse_translate(coord);
+        };
+    }
+}
+
 impl<DB: DrawingBackend, X: Ranged, Y: Ranged> ChartContext<DB, RangedCoord<X, Y>> {
     /// Get the range of X axis
     pub fn x_range(&self) -> Range<X::ValueType> {
@@ -365,6 +377,11 @@ impl<DB: DrawingBackend, X: Ranged, Y: Ranged> ChartContext<DB, RangedCoord<X, Y
         return self.drawing_area.get_y_range();
     }
 
+    /// Get the plotting area
+    pub fn plotting_area(&self) -> &DrawingArea<DB, RangedCoord<X, Y>> {
+        return &self.drawing_area;
+    }
+
     /// Defines a series label area
     pub fn define_series_label_area<'a, S: Into<ShapeStyle<'a>>>(
         &mut self,
