@@ -1,4 +1,4 @@
-use super::CoordTranslate;
+use super::{CoordTranslate, ReverseCoordTranslate};
 use crate::drawing::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
 use crate::style::ShapeStyle;
 
@@ -20,6 +20,13 @@ pub trait Ranged {
     fn range(&self) -> Range<Self::ValueType>;
 }
 
+/// The trait indicates the ranged value can be map reversely, which means
+/// an pixel-based cooridinate is given, it's possible to figureout the underlying
+/// logic value.
+pub trait ReversableRanged: Ranged {
+    fn unmap(&self, input: i32, limit: (i32, i32)) -> Option<Self::ValueType>;
+}
+
 /// The coordinate described by two ranged value
 pub struct RangedCoord<X: Ranged, Y: Ranged> {
     logic_x: X,
@@ -98,6 +105,15 @@ impl<X: Ranged, Y: Ranged> CoordTranslate for RangedCoord<X, Y> {
     }
 }
 
+impl<X: ReversableRanged, Y: ReversableRanged> ReverseCoordTranslate for RangedCoord<X, Y> {
+    fn reverse_translate(&self, input: BackendCoord) -> Option<Self::From> {
+        return Some((
+            self.logic_x.unmap(input.0, self.back_x)?,
+            self.logic_y.unmap(input.1, self.back_y)?,
+        ));
+    }
+}
+
 /// Represent a coordinate mesh for the two ranged value coordinate system
 pub enum MeshLine<'a, X: Ranged, Y: Ranged> {
     XMesh(BackendCoord, BackendCoord, &'a X::ValueType),
