@@ -222,6 +222,18 @@ impl<DB: DrawingBackend, CT: CoordTranslate> DrawingArea<DB, CT> {
         });
     }
 
+    /// Draw a single pixel
+    pub fn draw_pixel<ColorType: Color>(
+        &self,
+        pos: CT::From,
+        color: &ColorType,
+    ) -> Result<(), DrawingAreaError<DB>> {
+        let pos = self.coord.translate(&pos);
+        return self.backend_ops(|b| {
+            return b.draw_pixel(pos, color);
+        });
+    }
+
     /// Open the backend
     pub fn open(&self) -> Result<(), DrawingAreaError<DB>> {
         return self.backend_ops(|b| b.open());
@@ -397,3 +409,9 @@ impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
         });
     }
 }
+
+impl<DB: DrawingBackend, CT: CoordTranslate> DrawingArea<DB, CT> {
+    pub fn into_coord_spec(self) -> CT {
+        return self.coord;
+    }
+}
