@@ -15,6 +15,7 @@
 Plotters is a flexible drawing library for data visualization written in pure Rust for both native and WebAssembly.
 
 - Why plotting in Rust?
+
 Although rendering a figure doesn't requires too many computation power in most of the case,
 and programming language such as Python and Javascript is used for visualization purpose.
 Sometimes we need to make a figure based on huge amount of data, for example, rendering some
@@ -23,18 +24,18 @@ with many high-level programming language. In this case, Rust is a perfect candi
 figures, since it runs very fast while having high-level abstraction abilities.
 
 - What type of figure is supported?
+
 Currently, we support line series, point series and candlestick series.
 And the library is designed to be able to render multiple figure into a single image.
 But Plotter is aimed to be a platform that is fully extendable to supporting any other types of figure.
 
 - Plotting on HTML5 canvas
+
 Plotters currently supports backend that uses the HTML5 canvas. To use the WASM support, you can simply create
 `CanvasBackend` instead of other backend and all other API remains the same!
-Check the demo that uses Plotters with WASM at [here](http://home.chpc.utah.edu/~u0875014/wasm-test/).
-An sample WASM application is avaiable at examples/wasm-demo. To try it just simply run the shell script `start-server.sh` under 
-that directory.
-And the demo is avaiable at [this link](https://plumberserver.com/plotters-wasm-demo/index.html) as well.
 
+There's a small demo for Plotters + WASM under `examples/wasm-demo` directory of this repo.
+And you should be able to try the deployed version with the following [link](https://plumberserver.com/plotters-wasm-demo/index.html).
 
 ## Gallery
 
@@ -77,6 +78,16 @@ And the demo is avaiable at [this link](https://plumberserver.com/plotters-wasm-
     </div>
 </div>
 
+<div class="galleryItem">
+    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/mandelbrot.png">
+        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/mandelbrot.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Mandelbrot set
+        <a href="https://github.com/38/plotters/blob/master/examples/mandelbrot.rs">[code]</a>
+    </div>
+</div>
+
 ## Quick Start
 
 ```rust
@@ -110,8 +121,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 ## Concepts by examples
 
 ### Drawing Backends
-Plotters can use different drawing backends, such as SVG, BitMap, etc. And even real-time rendering,
-such as library. For example a bitmap drawing backend.
+Plotters can use different drawing backends, such as SVG, BitMap, etc, even real-time rendering. For example a bitmap drawing backend.
 
 ```rust
 use plotters::prelude::*;
@@ -249,8 +259,8 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     // Then we can draw a mesh
     chart.configure_mesh()
         // We can customize the maxium number of labels allowed for each axis
-        .x_labels(30)
-        .y_labels(10)
+        .x_labels(5)
+        .y_labels(5)
         // We can also change the format of the label text
         .y_label_formatter(&|x| format!("{:.3}", x))
         .draw()?;
@@ -302,19 +312,20 @@ pub mod style;
 pub mod prelude {
     pub use crate::chart::{ChartBuilder, ChartContext};
     pub use crate::coord::{
-        CoordTranslate, Ranged, RangedCoord, RangedCoordf32, RangedCoordf64, RangedCoordi32,
-        RangedCoordi64, RangedCoordu32, RangedCoordu64, RangedDate, RangedDateTime,
+        CoordTranslate, LogCoord, LogRange, LogScalable, Ranged, RangedCoord, RangedCoordf32,
+        RangedCoordf64, RangedCoordi32, RangedCoordi64, RangedCoordu32, RangedCoordu64, RangedDate,
+        RangedDateTime,
     };
     pub use crate::drawing::*;
     pub use crate::series::{Histogram, LineSeries, PointSeries};
     pub use crate::style::{
-        Black, Blue, Color, Cyan, FontDesc, Green, Magenta, Mixable, Palette, Palette100,
+        Black, Blue, Color, Cyan, FontDesc, Green, HSLColor, Magenta, Mixable, Palette, Palette100,
         Palette99, Palette9999, PaletteColor, RGBColor, Red, ShapeStyle, SimpleColor, TextStyle,
         Transparent, White, Yellow,
     };
 
     pub use crate::element::{
-        CandleStick, Circle, Cross, EmptyElement, OwnedText, Path, Rectangle, Text,
+        CandleStick, Circle, Cross, EmptyElement, OwnedText, Path, Pixel, Rectangle, Text,
     };
 
     #[allow(type_alias_bounds)]
