@@ -7,8 +7,8 @@ mod palette;
 use std::borrow::Borrow;
 
 pub use color::{
-    Black, Blue, Color, Cyan, Green, Magenta, Mixable, PaletteColor, RGBColor, Red, SimpleColor,
-    Transparent, White, Yellow,
+    Black, Blue, Color, Cyan, Green, HSLColor, Magenta, Mixable, PaletteColor, RGBColor, Red,
+    SimpleColor, Transparent, White, Yellow,
 };
 pub use font::{FontDesc, FontError, FontResult};
 pub use palette::*;
